==> choreonoid_1.5.0+dfsg+20150714+337+15~ubuntu14.10.1.tar.xz: choreonoid-1.5.0+dfsg+20150714+337+15~ubuntu14.10.1/src/Body/BodyMotionPoseProvider.h <==
/**
   @file
   @author Shin'ichiro Nakaoka
*/

#ifndef CNOID_BODY_BODY_MOTION_POSE_PROVIDER_H_INCLUDED
#define CNOID_BODY_BODY_MOTION_POSE_PROVIDER_H_INCLUDED

#include "Body.h"
#include "Link.h"
#include "PoseProvider.h"
#include "BodyMotion.h"
#include "ZMPSeq.h"
#include <cnoid/MultiAffine3Seq>
#include "exportdecl.h"

namespace cnoid {

class JointPath;
typedef boost::shared_ptr<JointPath> JointPathPtr;

class CNOID_EXPORT BodyMotionPoseProvider : public PoseProvider
{
public:
    BodyMotionPoseProvider();
    BodyMotionPoseProvider(BodyPtr body, BodyMotionPtr motion);

    void initialize(BodyPtr body, BodyMotionPtr motion);

    bool updateMotion();

    virtual Body* body() const;
    virtual double beginningTime() const;
    virtual double endingTime() const;
    virtual bool seek(double time);
    virtual bool seek(double time, int waistLinkIndex, const Vector3& waistTranslation);
    virtual int baseLinkIndex() const;
    virtual bool getBaseLinkPosition(Position& out_T) const;
    virtual void getJointPositions(std::vector< boost::optional<double> >& out_q) const;
    virtual boost::optional<Vector3> ZMP() const;

private:
    BodyPtr body_;
    BodyMotionPtr motion;
    ZMPSeqPtr zmpSeq;
    int minNumJoints;
    std::vector<Link*> footLinks;
    std::vector<JointPathPtr> ikPaths;
    MultiAffine3SeqPtr footLinkPositions;
    std::vector<double> qTranslated;
    Vector3 p_waist;
    Matrix3 R_waist;
    Vector3 ZMP_;

    bool seek(double time, int waistLinkIndex, const Vector3& waistTranslation, bool applyWaistTranslation);
};
}

#endif

==> choreonoid_1.6.0+dfsg+20180503+1250+23~ubuntu16.04.1.tar.xz: choreonoid-1.6.0+dfsg+20180503+1250+23~ubuntu16.04.1/src/Body/BodyMotionPoseProvider.h <==
/**
   @file
   @author Shin'ichiro Nakaoka
*/

#ifndef CNOID_BODY_BODY_MOTION_POSE_PROVIDER_H
#define CNOID_BODY_BODY_MOTION_POSE_PROVIDER_H

#include "Body.h"
#include "PoseProvider.h"
#include "BodyMotion.h"
#include "ZMPSeq.h"
#include <cnoid/MultiSE3MatrixSeq>
#include "exportdecl.h"

namespace cnoid {

class Link;

class JointPath;
typedef std::shared_ptr<JointPath> JointPathPtr;

class CNOID_EXPORT BodyMotionPoseProvider : public PoseProvider
{
public:
    BodyMotionPoseProvider();
    BodyMotionPoseProvider(Body* body, BodyMotionPtr motion);

    void initialize(Body* body, BodyMotionPtr motion);

    bool updateMotion();

    virtual Body* body() const;
    virtual double beginningTime() const;
    virtual double endingTime() const;
    virtual bool seek(double time);
    virtual bool seek(double time, int waistLinkIndex, const Vector3& waistTranslation);
    virtual int baseLinkIndex() const;
    virtual bool getBaseLinkPosition(Position& out_T) const;
    virtual void getJointPositions(std::vector< boost::optional<double> >& out_q) const;
    virtual boost::optional<Vector3> ZMP() const;

private:
    BodyPtr body_;
    BodyMotionPtr motion;
    ZMPSeqPtr zmpSeq;
    int minNumJoints;
    std::vector<Link*> footLinks;
    std::vector<JointPathPtr> ikPaths;
    MultiSE3MatrixSeqPtr footLinkPositions;
    std::vector<double> qTranslated;
    Vector3 p_waist;
    Matrix3 R_waist;
    Vector3 ZMP_;

    bool seek(double time, int waistLinkIndex, const Vector3& waistTranslation, bool applyWaistTranslation);
};

}

#endif
